define(
//begin v1.x content
({
        nomatchMessage: "Le password non corrispondono.",
		badPasswordMessage: "Password non valida."
})

//end v1.x content
);